{% extends "!layout.html" %}

{% block rootrellink %}
        <li><a href="{{ pathto('index') }}">Routes home</a>&nbsp;|&nbsp;</li>
        <li><a href="{{ pathto('contents') }}">Documentation</a>&raquo;</li>
{% endblock %}

{% block header %}
<div style="color: #D1361B; font-size: 70px; font-weight: bold; padding: 10px 0 0 10px;">Routes</div>
</div>
{% endblock %}