{% if version.endswith('(hg)') %}
<h3>Download Routes</h3>
<p>This documentation is for version <b>{{ version }}</b>, which is
  not released yet.</p>
<p>You can use it from the
  <a href="http://bitbucket.org/bbangert/routes/">Mercurial repo</a> or look for
  released versions in the <a href="http://pypi.python.org/pypi/Routes">Python
    Package Index</a>.</p>
{% else %}
<h3>Download Routes {{ version }}</h3>
<p>Get Routes from the <a href="http://pypi.python.org/pypi/Routes">Python Package
Index</a>, or install it with:</p>
<pre>easy_install -U Routes</pre>
{% endif %}

<h3>Bugs? Suggestions?</h3>

<p>Report them at the Bitbucket 
  <a href="http://www.bitbucket.org/bbangert/routes/issues/">tracker</a>.</p>
