{% extends "layout.html" %}
{% set title = 'Overview' %}
{% block body %}
<img src="_images/routes-logo.png" width="100" height="171"
style="float:left;margin:1em" />

  <p>Routes is a Python re-implementation of the Rails routes system for
  mapping URLs to application actions, and conversely to generate URLs. Routes
  makes it easy to create pretty and concise URLs that are RESTful with little
  effort.</p>
  
  <p>Routes allows conditional matching based on domain, cookies, HTTP method,
  or a custom function.  Sub-domain support is built in.  Routes comes with an
  extensive unit test suite.</p>

  <p>Buzzword Compliance: <em>REST</em>, <em>DRY</em></p>

<h2 style="clear: both;">New features</h2>

<div style="font-size:smaller">

<p>Version 1.12 (2010-02-28)</p>

<ul>
    <li>Explicit method of calling Mapper.routematch directly</li>
    <li>Submapper improvements for better resource handling</li>
    <li>Various bug fixes</li>
</ul>

<p>Version 1.11 (2009-09-28)</p>

<ul>
    <li>Completely new manual</li>
    <li>Add a group of routes under a common URL prefix</li>
</ul>


</div>

<p><a href="changes.html">Full changelog</a></p>


  <h2>Documentation</h2>
  <table class="contentstable" align="center" style="margin-left: 30px"><tr>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("contents") }}">Contents</a><br/>
         <span class="linkdescr">for a complete overview</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("search") }}">Search</a><br/>
         <span class="linkdescr">search the documentation</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("todo") }}">TODO</a><br/>
         <span class="linkdescr">future development plans</span></p>
    </td><td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("genindex") }}">General Index</a><br/>
         <span class="linkdescr">all functions, classes, terms</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("modindex") }}">Module Index</a><br/>
         <span class="linkdescr">quick access to all documented modules</span></p>
    </td></tr>
  </table>
  
  <p>Download <a href="http://routes.groovie.org/routes.pdf">Routes PDF documentation</a>.</p>

  <h2>Developers / Source Code</h2>
  <p>Routes' Mercurial repository can be found at
    <a href="http://bitbucket.org/bbangert/routes/"><tt>http://bitbucket.org/bbangert/routes/</tt></a>.</p>
    
    <p>To check it out:</p>
    
      <pre>hg clone http://www.bitbucket.org/bbangert/routes</pre>

{% endblock %}
